# This package contains no ELF objects, but does have to store a symlink to
# the nauty binary in a package with an arch-specific name.
%global debug_package %{nil}

%global upstreamver 4r7
%global majorver %(cut -dp -f1 <<< %{upstreamver})
%global pkgname grape

Name:           gap-pkg-%{pkgname}
Version:        %(sed -r "s/r|p/./g" <<< %{upstreamver})
Release:        8%{?dist}
Summary:        GRaph Algorithms using PErmutation groups

License:        GPLv2+
URL:            http://www.maths.qmul.ac.uk/~leonard/%{pkgname}/
Source0:        http://www.maths.qmul.ac.uk/~leonard/%{pkgname}/%{pkgname}%{majorver}/%{pkgname}%{upstreamver}.tar.gz

BuildRequires:  nauty
BuildRequires:  gap-devel
BuildRequires:  tth

Requires:       nauty
Requires:       gap-core

%description
GRAPE is a package for computing with graphs and groups, and is
primarily designed for constructing and analyzing graphs related to
groups, finite geometries, and designs.

%prep
%setup -q -n %{pkgname}

# Remove prebuilt nauty and nauty sources so we use the system version
rm -fr bin/* nauty22

fixtimestamp() {
  touch -r $1.orig $1
  rm -f $1.orig
}

# Fix encoding
iconv -f iso8859-1 -t utf-8 PackageInfo.g > PackageInfo.g.utf8
touch -r PackageInfo.g PackageInfo.g.utf8
mv -f PackageInfo.g.utf8 PackageInfo.g

# Fix broken references to the GAP manual
sed -i.orig 's/Reference:/ref:/g' doc/grape.tex
fixtimestamp doc/grape.tex

%build
# Link to main GAP documentation
ln -s %{_gap_dir}/etc ../../etc
ln -s %{_gap_dir}/doc ../../doc
pushd doc
./make_doc
popd
rm -f ../../{doc,etc}

%install
. %{_gap_dir}/sysinfo.gap
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname} %{buildroot}%{_gap_dir}/pkg
mkdir %{buildroot}%{_gap_dir}/pkg/%{pkgname}/bin/$GAParch
ln -s %{_bindir}/dreadnaut \
  %{buildroot}%{_gap_dir}/pkg/%{pkgname}/bin/$GAParch/dreadnautB
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{doc/make_doc,COPYING,gpl.txt,README}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,idx,ilg,ind,log,tex,toc}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/.Rhistory

%check
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" << EOF 2>&1 | tee log
Test( "tst/testall.tst", rec( compareFunction := "uptowhitespace" ) );
EOF
! grep -Fq Error log
rm -f log

%files
%doc README
%license COPYING gpl.txt
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.7-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jan 11 2018 Jerry James <loganjerry@gmail.com> - 4.7-7
- Build as an archful package instead of noarch because the nauty symlink has
  to be stored in a directory with an arch-specific name

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.7-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Apr 22 2016 Jerry James <loganjerry@gmail.com> - 4.7-4
- Build for nauty now that it is available

* Thu Apr  7 2016 Jerry James <loganjerry@gmail.com> - 4.7-3
- Rebuild for gap 4.8.3

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jan 20 2016 Jerry James <loganjerry@gmail.com> - 4.7-1
- New upstream version
- Drop upstreamed bliss patch

* Wed Nov 11 2015 Jerry James <loganjerry@gmail.com> - 4.6.1-2
- Drop scriptlets; gap-core now uses rpm file triggers
- Rebuild documentation from source
- Turn test failures into build failures
- New version of bliss patch from upstream

* Mon Oct 19 2015 Jerry James <loganjerry@gmail.com> - 4.6.1-1
- Initial RPM
